#[non_exhaustive]pub struct BlockingOptions {
pub min_nonzero_samples_for_signal: usize,
pub strong_p95_threshold: u64,
pub strong_peak_threshold: u64,
pub strong_nonzero_share_permille: u64,
pub strong_min_samples: usize,
}Expand description
Blocking-pressure suspect thresholds and minimum-sample guards.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min_nonzero_samples_for_signal: usizeMinimum number of non-zero blocking queue samples needed before blocking signal can trigger.
strong_p95_threshold: u64Blocking queue-depth p95 threshold used for stronger blocking-pressure suspect evidence.
strong_peak_threshold: u64Blocking queue-depth peak threshold used for stronger blocking-pressure suspect evidence.
Minimum non-zero blocking sample share (permille) for stronger blocking-pressure suspect evidence.
strong_min_samples: usizeMinimum blocking sample count before strong blocking heuristics can trigger.