#[non_exhaustive]pub struct TemporalOptions {
pub min_request_count: usize,
pub min_segment_request_count: usize,
pub share_shift_permille: u64,
pub p95_shift_ratio_numerator: u64,
pub p95_shift_ratio_denominator: u64,
pub emit_on_suspect_shift: bool,
pub suppress_runtime_sparse_suspect_shift_without_supporting_movement: bool,
}Expand description
Temporal-shift thresholds used for early/late suspect comparisons.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min_request_count: usizeMinimum completed requests required before temporal segmentation heuristics run.
min_segment_request_count: usizeMinimum completed requests required in each temporal segment for suspect comparison.
Minimum queue/service-share movement (permille) required to flag temporal suspect shift evidence.
p95_shift_ratio_numerator: u64Numerator for temporal p95 ratio movement heuristic threshold.
p95_shift_ratio_denominator: u64Denominator for temporal p95 ratio movement heuristic threshold.
emit_on_suspect_shift: boolWhether to emit temporal suspect-shift warnings when movement heuristics trigger.
suppress_runtime_sparse_suspect_shift_without_supporting_movement: boolWhether to suppress runtime-sparse suspect-shift warnings when supporting movement evidence is absent.