pub enum AnalyzeConfigError {
InvalidOverrideSyntax {
raw: String,
},
UnknownOverridePath {
path: String,
suggestion: Option<&'static str>,
},
InvalidOverrideValue {
path: &'static str,
value: String,
expected: &'static str,
},
InvalidConfigValue {
path: &'static str,
message: String,
},
MissingAnalyzerTable,
MissingSchemaVersion,
UnsupportedSchemaVersion {
found: u64,
supported: u64,
},
InvalidToml {
message: String,
},
}Expand description
Validation and configuration errors for analyzer options and checked triage APIs.
Variants
InvalidOverrideSyntax
Invalid override assignment syntax.
UnknownOverridePath
Unknown semantic override path.
Fields
InvalidOverrideValue
Override value could not be parsed for its path type.
Fields
InvalidConfigValue
Semantic option value failed validation.
Fields
MissingAnalyzerTable
Missing [analyzer] table in configuration input.
MissingSchemaVersion
Missing schema_version in configuration input.
UnsupportedSchemaVersion
Unsupported schema_version in configuration input.
Fields
InvalidToml
Invalid TOML error.